*************************************************************
fortnet-python: Python Tools for the Fortnet Software Package
*************************************************************

|license|
|latest version|
|doi|
|issues|

fortnet-python provides tools to generate compatible datasets as well as extract
results obtained by the neural network implementation
`Fortnet <https://github.com/vanderhe/fortnet>`_.

|logo|

Installation
============

The package can be installed via conda-forge::

  conda install fortnet-python

Alternatively, the package can be downloaded and installed via pip into the
active Python interpreter (preferably using a virtual python environment) by::

  pip install fortnet-python

or into the user space issueing::

  pip install --user fortnet-python

Documentation
=============

|docs status|

Consult following resources for documentation:

* `Step-by-step instructions with selected examples (Fortnet Recipes)
  <https://fortnet.readthedocs.io/>`_

Contributing
============

New features, bug fixes, documentation, tutorial examples and code testing is
welcome during the ongoing fortnet-python development!

The project is
`hosted on github <https://github.com/vanderhe/fortnet-python/>`_.
Please check `CONTRIBUTING.rst <CONTRIBUTING.rst>`_ for guide lines.

I am looking forward to your pull request!

License
=======

fortnet-python is released under the BSD 2-clause license. See the included
`LICENSE <LICENSE>`_ file for the detailed licensing conditions.

.. |logo| image:: ./utils/art/logo.svg
    :alt: Fortnet logo
    :width: 90
    :target: https://github.com/vanderhe/fortnet/

.. |license| image:: https://img.shields.io/github/license/vanderhe/fortnet-python
    :alt: BSD-2-Clause
    :scale: 100%
    :target: https://opensource.org/licenses/BSD-2-Clause

.. |latest version| image:: https://img.shields.io/github/v/release/vanderhe/fortnet-python
    :target: https://github.com/vanderhe/fortnet-python/releases/latest

.. |doi| image:: https://zenodo.org/badge/356394988.svg
   :target: https://zenodo.org/badge/latestdoi/356394988

.. |docs status| image:: https://readthedocs.org/projects/fortnet/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://fortnet-python.readthedocs.io/en/latest/

.. |issues| image:: https://img.shields.io/github/issues/vanderhe/fortnet-python.svg
    :target: https://github.com/vanderhe/fortnet-python/issues/

.. |build status| image:: https://img.shields.io/github/workflow/status/vanderhe/fortnet-python/Build%20and%20Test
    :target: https://github.com/vanderhe/fortnet-python/actions/
